#!/bin/sh
export PATH="/sbin:/usr/sbin:/bin:/usr/bin"

WORK_DIR="/etc/oem_def_data"
echo "Working dir : $WORK_DIR"

#TARGET_DIR=`pwd`/work
TARGET_DIR="/"
echo "Target dir : $TARGET_DIR"

OEM_DEF_INIT_LOG=${TARGET_DIR}/etc/sysconfig/oem_def_init.log

# if already OEM default config is maid, exit
[ -f $OEM_DEF_INIT_LOG ] && exit 0


#
# default config file path
# if si ver >= 4.27, umconfig.txt is replaced with route.txt
PATH_ROUTE_TXT=${TARGET_DIR}/etc/sysconfig/route.txt
PATH_RTPRTSP=${TARGET_DIR}/opt/nss/etc/FwConf/rtsp.conf
PATH_IPCCTVDNS=${TARGET_DIR}/opt/nss/etc/ascd.conf
PATH_DEF_COMS=${TARGET_DIR}/etc/sysconfig/defcoms.conf
PATH_NAMES_CONF=${TARGET_DIR}/etc/sysconfig/names.conf

#
# default config file base
DF_FULL_ROUTE=${WORK_DIR}/full_route.txt
DF_LIMIT_ROUTE=${WORK_DIR}/limit_route.txt
DF_RTPRTSP_BASE=${WORK_DIR}/rtsp-base
DF_IPCCTVDNS_BASE=${WORK_DIR}/ascd-base

#
# default COM/AUX config
DF_COM_MODE="c"
DF_AUX_MODE="p"
WEB_FD_FLAG=0


#
# funtions

# make /etc/sysconfig/network-scripts/ifcfg-{dev}
# usage : mk_ifcfg {dev} {static|dchp} [{ip} {netmask} {network} {broadcast} {yes|no}]
mk_ifcfg ()
{
	if [ -z "$1" ]; then
		return -1
	fi
	if [ "$2" != "static" -a "$2" != "dhcp" ]; then
		return -1
	fi

	IFCFG_FILE=${TARGET_DIR}/etc/sysconfig/network-scripts/ifcfg-$1

	echo DEVICE\=\"$1\" > ${IFCFG_FILE}
	echo IPADDR\=\"$3\" >> ${IFCFG_FILE}
	echo NETMASK\=\"$4\" >> ${IFCFG_FILE}
	echo NETWORK\=\"$5\" >> ${IFCFG_FILE}
	echo BROADCAST\=\"$6\" >> ${IFCFG_FILE}
	if [ -z "$7" -o "$7" = "yes" ]; then
		echo ONBOOT\=\"yes\" >> ${IFCFG_FILE}
	else
		echo ONBOOT\=\"no\" >> ${IFCFG_FILE}
	fi
	if [ "$2" = "static" ]; then
		echo BOOTPROTO\=\"none\" >> ${IFCFG_FILE}
	else
		echo BOOTPROTO\=\"$2\" >> ${IFCFG_FILE}
	fi
	
	return 0
}

# make /etc/sysconfig/network
# usage : mk_network {gateway} {gatewaydev}
mk_network ()
{
	NETWORK_FILE=${TARGET_DIR}/etc/sysconfig/network

	echo NETWORKING\=\"yes\" > ${NETWORK_FILE}
	echo HOSTNAME\=\"NetCAM\" >> ${NETWORK_FILE}
	echo GATEWAY\=\"$1\" >> ${NETWORK_FILE}
	echo GATEWAYDEV\=\"$2\" >> ${NETWORK_FILE}
	echo FORWARD_IPV4\=\"no\" >> ${NETWORK_FILE}
	echo DHCPD_ENABLE\=\"no\" >> ${NETWORK_FILE}
}


# edit /opt/nss/etc/ascd.conf
# usage : edit_ascd {yes|no} {url}
edit_ascd ()
{
#echo ${PATH_IPCCTVDNS}
[ -f ${PATH_IPCCTVDNS}.new ] && rm ${PATH_IPCCTVDNS}.new
	while read LLL; do
		TEST_PATTERN=${LLL:0:12}
#echo ">>> $TEST_PATTERN"
		if [ "$TEST_PATTERN" = "AOIP_ENABLE=" ]; then
			echo AOIP_ENABLE\=$1 >> ${PATH_IPCCTVDNS}.new
		elif [ "$TEST_PATTERN" = "AOIP_SERVER=" ]; then
			echo AOIP_SERVER\=\"$2\" >> ${PATH_IPCCTVDNS}.new
		else
			echo "$LLL" >> ${PATH_IPCCTVDNS}.new
		fi
	done < ${PATH_IPCCTVDNS}
	mv ${PATH_IPCCTVDNS}.new ${PATH_IPCCTVDNS}
}


# edit /opt/nss/etc/FwConf/rtsp.conf
# usage : edit_rtsp {0|1}
edit_rtsp ()
{
#echo ${PATH_RTPRTSP}
[ -f ${PATH_RTPRTSP}.new ] && rm ${PATH_RTPRTSP}.new
	while read LLL; do
		TEST_PATTERN=${LLL:0:12}
#echo ">>> $TEST_PATTERN"
		if [ "$TEST_PATTERN" = "RTSP_ENABLE=" ]; then
			echo RTSP_ENABLE\=$1 >> ${PATH_RTPRTSP}.new
		else
			echo "$LLL" >> ${PATH_RTPRTSP}.new
		fi
	done < ${PATH_RTPRTSP}
	mv ${PATH_RTPRTSP}.new ${PATH_RTPRTSP}
}


make_def_coms ()
{
	echo "DF_COM_MODE=$DF_COM_MODE" > $PATH_DEF_COMS
	echo "DF_AUX_MODE=$DF_AUX_MODE" >> $PATH_DEF_COMS
	echo "WEB_FD_FLAG=$WEB_FD_FLAG" >> $PATH_DEF_COMS
}


# write log
write_log()
{
	echo $* >> $OEM_DEF_INIT_LOG
}


get_oem_code()
{
	PNCODE=`grep SYF_STR1 /proc/driver/sy_basic_conf`
#	echo "$PNCODE"
	OEM_PNCODE=${PNCODE:39:2}
	OEM_PNCODE_SZ=${#OEM_PNCODE}
	echo "$OEM_PNCODE , $OEM_PNCODE_SZ"
	if [ $OEM_PNCODE_SZ -lt 2 ]; then
		echo "Wrong OEM code : $"
	fi
}


### Time zone related
###

TZ_CONF=/etc/sysconfig/tz.conf
TZ_LIST=/usr/share/zone.list
TZ_TGZ=/usr/share/zone.tar.gz

function is_valid_tz()
{
        IS_VALID=`grep -c ^$1$ $TZ_LIST`
        return $IS_VALID
}

function change_tz()
{
        WORK_DIR=/tzwork

        mkdir $WORK_DIR
        cd $WORK_DIR
        tar xzf $TZ_TGZ

        cp $WORK_DIR/zoneinfo/$1 /etc/sysconfig/localtime
        echo "TIMEZONE=$1" > ${TZ_CONF}
        cd /
        rm -rf $WORK_DIR
}

#
### Time zone related


##### Main start

get_oem_code

write_log "Start making def-conf"

case "$OEM_PNCODE" in
	0A)	# CV 1.3M/2M
		mk_ifcfg eth0 dhcp
		cp -a $DF_RTPRTSP_BASE $PATH_RTPRTSP
		edit_rtsp 1
		;;
	0B)	# Dongyang Uni
		. /var/log/fw_sensor_pncode
		case "$FW_SENSOR" in
			0l)
				DF_COM_MODE="n"
				;;
			*)
				DF_COM_MODE="c"
		esac
		DF_AUX_MODE="p"
		WEB_FD_FLAG=1
		;;
#	0C)	# FD
#		;;
	0D)	# Orion T (full access)
		echo "SERVER_NAME=\"VIEWZ\"" > $PATH_NAMES_CONF
###		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
		;;
	0d)	# Orion T (limited access)
		echo "SERVER_NAME=\"VIEWZ\"" > $PATH_NAMES_CONF
		cp -a $DF_LIMIT_ROUTE $PATH_ROUTE_TXT
		;;
	0[EFe])	# Ronix 1.3M/2M 60Hz, Eneo 1.3M/2M, Ronix 50Hz
		mk_ifcfg eth0 static 192.168.1.10 255.255.255.0 192.168.1.0 192.168.1.255 yes
		mk_network 192.168.1.1 eth0
###		cp -a $DF_LIMIT_ROUTE $PATH_ROUTE_TXT
		cp -a $DF_RTPRTSP_BASE $PATH_RTPRTSP
		edit_rtsp 1
		;;
	0G)	# URC
		mk_ifcfg eth0 dhcp
		mk_ifcfg ra0 dhcp 10.20.30.40 255.255.255.0 10.20.30.0 10.20.30.255 no
#		DF_COM_MODE="n"
		;;
	0H)	# VI
		DEFAULT_TZ=US/Pacific
		is_valid_tz $DEFAULT_TZ
		if  [ $? -ne 1 ]; then
			echo "$DEFAULT_TZ is not valid time zone"
			exit 1
		fi
		change_tz $DEFAULT_TZ
		;;
#	0I)	# GPI360
#		;;
	0J)	# MD NetCAM
		mk_ifcfg eth0 dhcp
		mk_ifcfg ra0 dhcp 10.20.30.40 255.255.255.0 10.20.30.0 10.20.30.255 no
		;;
#	0K)	# MD NVS
#		;;
	0L)	# MD iVideon
		mk_ifcfg eth0 dhcp
		;;
##	0M)	# MD 3G GSM
##		;;
##	0N)	# Union
##		;;
#	0O)	# TNH (Capital o)
#		;;
#	0P)	# IST
#		;;
#	0Q)	# Lucoms
#		;;
#	0R)	# Monitor Closely
#		;;

	0S)	# Camtron Ikegami
		mk_ifcfg eth0 static 192.168.1.100 255.255.255.0 192.168.1.0 192.168.1.255 yes
		mk_network 192.168.1.1 eth0

		DEFAULT_TZ=Asia/Tokyo
		is_valid_tz $DEFAULT_TZ
		if  [ $? -ne 1 ]; then
			echo "$DEFAULT_TZ is not valid time zone"
			exit 1
		fi
		change_tz $DEFAULT_TZ
		;;

	0U)	# DW
		DEFAULT_TZ=US/Pacific
		is_valid_tz $DEFAULT_TZ
		if  [ $? -ne 1 ]; then
			echo "$DEFAULT_TZ is not valid time zone"
			exit 1
		fi
		change_tz $DEFAULT_TZ
		;;

	0s)	# samsun medicam
		echo "SERVER_NAME=\"CCTV_CAMERA\"" > $PATH_NAMES_CONF
		;;
	0[cb])	# Cynix
		mk_ifcfg eth0 static 192.168.10.100 255.255.255.0 192.168.10.0 192.168.10.255 yes
		mk_network 192.168.10.1 eth0
		;;
	0g)	# Biges
		mk_ifcfg eth0 static 192.168.0.251 255.255.0.0 192.168.0.0 192.168.255.255 yes
		mk_network 192.168.0.1 eth0
		;;
#	"00")
	*)
		# seyeon default
#		mk_ifcfg eth0 static 10.20.30.40 255.255.255.0 10.20.30.0 10.20.30.255 yes
#		mk_ifcfg eth1 static 11.20.30.40 255.255.255.0 11.20.30.0 11.20.30.255 yes
#		mk_ifcfg ra0 static 10.20.30.40 255.255.255.0 10.20.30.0 10.20.30.255 no
#		mk_network 10.10.1.1 eth0
###		cp -a $DF_FULL_ROUTE $PATH_ROUTE_TXT
#		cp -a $DF_RTPRTSP_BASE $PATH_RTPRTSP
#		cp -a $DF_IPCCTVDNS_BASE $PATH_IPCCTVDNS
#		DF_COM_MODE="c"
#		DF_AUX_MODE="p"
#		WEB_FD_FLAG=0
		;;
esac

write_log `date`

if [ ! -f $PATH_DEF_COMS ]; then
		make_def_coms
		write_log "Port def COM=$DF_COM_MODE, AUX=$DF_AUX_MODE, WEB_FD_FLAG=$WEB_FD_FLAG"
fi

exit 0



